@@ -1,7 +1,9 @@
+use std::env;
 use std::io::{self, Read, Write};
 
 const CHUNK_SIZE: usize = 16 * 1024;
 fn main() {
+    let silent = env::var("PPVR_SILENT").unwrap_or(String::new()).len() > 0;
     let mut total_bytes = 0;
     loop {
         let mut buffer = [0u8; CHUNK_SIZE];
@@ -13,5 +15,7 @@ fn main() {
         total_bytes += num_read;
         io::stdout().write_all(&buffer[..num_read]).unwrap();
     }
-    eprintln!("num_read: {:?}", total_bytes);
+    if !silent {
+        eprintln!("num_read: {:?}", total_bytes);
+    }
 }
